@@ -1,14 +1,14 @@
 """Tests for the models of the ``roadmap`` app."""
 from django.test import TestCase
 
-from .factories import MilestoneTranslationENFactory, EventTranslationENFactory
+from .factories import EventFactory, MilestoneFactory
 
 
 class MilestoneTestCase(TestCase):
     """Tests for the ``Milestone`` model."""
     def test_model(self):
         """Should be able to instantiate and save."""
-        obj = MilestoneTranslationENFactory()
+        obj = MilestoneFactory()
         self.assertTrue(obj.pk)
 
 
@@ -16,5 +16,5 @@ class EventTestCase(TestCase):
     """Tests for the ``Event`` model."""
     def test_model(self):
         """Should be able to instantiate and save."""
-        obj = EventTranslationENFactory()
+        obj = EventFactory()
         self.assertTrue(obj.pk)
